@@ -2,10 +2,13 @@ import sys
 
 from gy_redis.manager import (
     RedisManager,
+)
+
+from gy_redis.handler import (
+    RedisBytesHandler,
+    RedisImageHandler,
+    RedisDictHandler,
     RedisConnector,
-    RedisBytesHander,
-    RedisDictHander,
-    RedisImageHander
 )
 
 if sys.version_info >= (3, 8):
@@ -35,7 +38,7 @@ except AttributeError:
 __all__ = [
     "RedisManager",
     "RedisConnector",
-    "RedisBytesHander",
-    "RedisDictHander",
-    "RedisImageHander",
+    "RedisBytesHandler",
+    "RedisDictHandler",
+    "RedisImageHandler",
 ]
